@@ -127,7 +127,8 @@ for (j in 1:sim) {
       
       
       #captureError<-tryCatch(truthTable(s.qca.data,  outcome=c("OUT"),  n.cut=10, incl.cut1=inclcut[k], include = "?", neg.out=neg.out,
-      captureError<-tryCatch(truthTable(s.qca.data,  outcome=c("OUT"),  n.cut=10, incl.cut=inclcut[k], include = "?", neg.out=neg.out,
+      
+      captureError<-tryCatch(truthTable(s.qca.data,  outcome=c("OUT"),  n.cut=n, incl.cut=inclcut[k], neg.out=neg.out,
                                         conditions= c(names(s.qca.data[,!(names(s.qca.data) %in% 'OUT')])),details = TRUE, show.cases = TRUE)[[1]][,1], error=function(e) e)
       
       # if (grepl("replacement has 0 items",captureError)){data$OUT[kk]<-NA}
